@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2016 Fanout, Inc.
+ * Copyright (C) 2012-2020 Fanout, Inc.
  *
  * This file is part of Pushpin.
  *
@@ -553,7 +553,12 @@ public:
 		{
 			// switch on multi support
 			multi = true;
-			startKeepAlive(); // re-setup keep alive
+
+			if(!pausing)
+			{
+				// re-setup keep alive
+				startKeepAlive();
+			}
 		}
 
 		refreshTimeout();
@@ -1261,7 +1266,10 @@ int ZhttpRequest::bytesAvailable() const
 
 int ZhttpRequest::writeBytesAvailable() const
 {
-	return d->outCredits;
+	if(d->responseBodyBuf.size() <= IDEAL_CREDITS)
+		return (IDEAL_CREDITS - d->responseBodyBuf.size());
+	else
+		return 0;
 }
 
 bool ZhttpRequest::isFinished() const
