@@ -67,6 +67,7 @@
 #include "publishlastids.h"
 #include "instruct.h"
 #include "httpsession.h"
+#include "wssession.h"
 #include "controlrequest.h"
 #include "conncheckworker.h"
 #include "refreshworker.h"
@@ -83,7 +84,6 @@
 #define PROXY_RPC_TIMEOUT 10000
 #define DEFAULT_WS_KEEPALIVE_TIMEOUT 55
 #define DEFAULT_WS_SENDDELAYED_TIMEOUT 1
-#define WSCONTROL_REQUEST_TIMEOUT 8000
 #define SUBSCRIBED_DELAY 1000
 
 #define INSPECT_WORKERS_MAX 10
@@ -387,158 +387,6 @@ private slots:
 	}
 };
 
-class WsSession : public QObject
-{
-	Q_OBJECT
-
-public:
-	QString cid;
-	int nextReqId;
-	QString channelPrefix;
-	HttpRequestData requestData;
-	QString route;
-	QString sid;
-	QHash<QString, QString> meta;
-	QHash<QString, QStringList> channelFilters; // k=channel, v=list(filters)
-	QSet<QString> channels;
-	QSet<QString> implicitChannels;
-	int ttl;
-	QByteArray keepAliveType;
-	QByteArray keepAliveMessage;
-	QByteArray delayedType;
-	QByteArray delayedMessage;
-	QHash<int, qint64> pendingRequests;
-	QTimer *expireTimer;
-	QTimer *delayedTimer;
-	QTimer *requestTimer;
-
-	WsSession(QObject *parent = 0) :
-		QObject(parent),
-		nextReqId(0)
-	{
-		expireTimer = new QTimer(this);
-		expireTimer->setSingleShot(true);
-		connect(expireTimer, &QTimer::timeout, this, &WsSession::expireTimer_timeout);
-
-		delayedTimer = new QTimer(this);
-		delayedTimer->setSingleShot(true);
-		connect(delayedTimer, &QTimer::timeout, this, &WsSession::delayedTimer_timeout);
-
-		requestTimer = new QTimer(this);
-		requestTimer->setSingleShot(true);
-		connect(requestTimer, &QTimer::timeout, this, &WsSession::requestTimer_timeout);
-	}
-
-	~WsSession()
-	{
-		expireTimer->disconnect(this);
-		expireTimer->setParent(0);
-		expireTimer->deleteLater();
-
-		delayedTimer->disconnect(this);
-		delayedTimer->setParent(0);
-		delayedTimer->deleteLater();
-
-		requestTimer->disconnect(this);
-		requestTimer->setParent(0);
-		requestTimer->deleteLater();
-	}
-
-	void refreshExpiration()
-	{
-		expireTimer->start(ttl * 1000);
-	}
-
-	void flushDelayed()
-	{
-		if(delayedTimer->isActive())
-		{
-			delayedTimer->stop();
-			delayedTimer_timeout();
-		}
-	}
-
-	void sendDelayed(const QByteArray &type, const QByteArray &message, int timeout)
-	{
-		flushDelayed();
-
-		delayedType = type;
-		delayedMessage = message;
-		delayedTimer->start(timeout * 1000);
-	}
-
-	void ack(int reqId)
-	{
-		if(pendingRequests.contains(reqId))
-		{
-			pendingRequests.remove(reqId);
-			setupRequestTimer();
-		}
-	}
-
-signals:
-	void send(int reqId, const QByteArray &type, const QByteArray &message);
-	void expired();
-	void error();
-
-private:
-	void setupRequestTimer()
-	{
-		if(!pendingRequests.isEmpty())
-		{
-			// find next expiring request
-			qint64 lowestTime = -1;
-			QHashIterator<int, qint64> it(pendingRequests);
-			while(it.hasNext())
-			{
-				it.next();
-				qint64 time = it.value();
-
-				if(lowestTime == -1 || time < lowestTime)
-					lowestTime = time;
-			}
-
-			int until = int(lowestTime - QDateTime::currentMSecsSinceEpoch());
-
-			requestTimer->start(qMax(until, 0));
-		}
-		else
-		{
-			requestTimer->stop();
-		}
-	}
-
-private slots:
-	void expireTimer_timeout()
-	{
-		log_debug("timing out ws session: %s", qPrintable(cid));
-
-		emit expired();
-	}
-
-	void delayedTimer_timeout()
-	{
-		int reqId = nextReqId++;
-
-		QByteArray message = delayedMessage;
-		delayedMessage.clear();
-
-		pendingRequests[reqId] = QDateTime::currentMSecsSinceEpoch() + WSCONTROL_REQUEST_TIMEOUT;
-		setupRequestTimer();
-
-		emit send(reqId, delayedType, message);
-	}
-
-	void requestTimer_timeout()
-	{
-		// on error, destroy any other pending requests
-		pendingRequests.clear();
-		setupRequestTimer();
-
-		emit error();
-	}
-};
-
 class Subscription;
 
 class CommonState
@@ -1646,7 +1494,7 @@ public:
 
 		if(config.pushInHttpPort != -1)
 		{
-			controlHttpServer = new SimpleHttpServer(this);
+			controlHttpServer = new SimpleHttpServer(config.pushInHttpMaxHeadersSize, config.pushInHttpMaxBodySize, this);
 			connect(controlHttpServer, &SimpleHttpServer::requestReady, this, &Private::controlHttpServer_requestReady);
 			controlHttpServer->listen(config.pushInHttpAddr, config.pushInHttpPort);
 
@@ -2244,7 +2092,7 @@ private slots:
 		}
 		else if(req->method() == "refresh")
 		{
-			RefreshWorker *w = new RefreshWorker(req, proxyControlClient, this);
+			RefreshWorker *w = new RefreshWorker(req, proxyControlClient, &cs.wsSessionsByChannel, this);
 			connect(w, &RefreshWorker::finished, this, &Private::deferred_finished);
 			deferreds += w;
 		}
@@ -2709,10 +2557,13 @@ private slots:
 			}
 
 			// track proxy connections for reporting
-			stats->processExternalPacket(p);
+			bool localReplaced = stats->processExternalPacket(p);
 
-			// forward the packet. this will stamp the from field and keep the rest
-			stats->sendPacket(p);
+			if(!localReplaced)
+			{
+				// forward the packet. this will stamp the from field and keep the rest
+				stats->sendPacket(p);
+			}
 
 			// update session
 			if(stateClient && !sid.isEmpty() && p.type == StatsPacket::Connected)
